@@ -330,9 +330,9 @@ def test_generate_slave_message_payload():
     }
     result = generate_msgpack_message_payload(data)
     assert msgpack.unpackb(result) == {
-        b'endpoint': b'v0/slave_send',
-        b'data': {
-            b'ids': [1, 2, 3, 4]
+        'endpoint': 'v0/slave_send',
+        'data': {
+            'ids': [1, 2, 3, 4]
         }
     }
 
